==> iam-0.8.2-sources.jar: software/amazon/awscdk/services/iam/cloudformation/AccessKeyResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-accesskey.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.AccessKeyResource")
public class AccessKeyResource extends software.amazon.awscdk.Resource {
    protected AccessKeyResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.AccessKeyResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::AccessKey``.
     * @param parent the ``cdk.Construct`` this ``AccessKeyResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``AccessKeyResource``
     */
    public AccessKeyResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.iam.cloudformation.AccessKeyResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @cloudformation_attribute SecretAccessKey
     */
    public software.amazon.awscdk.services.iam.AccessKeySecretAccessKey getAccessKeySecretAccessKey() {
        return this.jsiiGet("accessKeySecretAccessKey", software.amazon.awscdk.services.iam.AccessKeySecretAccessKey.class);
    }
}

==> iam-0.9.0-sources.jar: software/amazon/awscdk/services/iam/cloudformation/AccessKeyResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-accesskey.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:54:34.627Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.AccessKeyResource")
public class AccessKeyResource extends software.amazon.awscdk.Resource {
    protected AccessKeyResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.AccessKeyResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::AccessKey``.
     * @param parent the ``cdk.Construct`` this ``AccessKeyResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``AccessKeyResource``
     */
    public AccessKeyResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.iam.cloudformation.AccessKeyResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute SecretAccessKey
     */
    public software.amazon.awscdk.services.iam.AccessKeySecretAccessKey getAccessKeySecretAccessKey() {
        return this.jsiiGet("accessKeySecretAccessKey", software.amazon.awscdk.services.iam.AccessKeySecretAccessKey.class);
    }

    public software.amazon.awscdk.services.iam.AccessKeyId getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.iam.AccessKeyId.class);
    }
}
